<?xml version="1.0" ?><!DOCTYPE TS><TS language="da" version="2.1">
<context>
    <name>CustomDialog</name>
    <message>
        <location filename="dialog.cpp" line="15"/>
        <source>Live environment detected. Please select the root partition of the
 system you want to modify (only Linux partitions are displayed)</source>
        <translation>Livemiljø registreret. Vælg venligst rodpartitionen på
 det system du vil ændre (der vises kun Linux-partitioner)</translation>
    </message>
    <message>
        <location filename="dialog.cpp" line="22"/>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <location filename="dialog.cpp" line="23"/>
        <source>Cancel</source>
        <translation>Annuller</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="mainwindow.ui" line="32"/>
        <source>Options</source>
        <translation>Valgmuligheder</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="38"/>
        <source>Kernel parameters</source>
        <translation>Kerneparametre</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="58"/>
        <source>Set to &apos;0&apos; to boot immediately without displaying the menu, or to &apos;-1&apos; to wait indefinitely</source>
        <translation>Indstil til &apos;0&apos; for at opstarte med det samme uden at vise menuen, eller til &apos;-1&apos; for at vente uendeligt</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="61"/>
        <source>Menu timeout</source>
        <translation>Timeout for menu</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="74"/>
        <source>Boot to</source>
        <translation>Opstart til</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="81"/>
        <source>Use simplified menu structure without submenus</source>
        <translation>Brug forenklet menustruktur uden undermenuer</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="84"/>
        <source>Use flat menus (no submenus)</source>
        <translation>Brug flade menuer (ingen undermenuer)</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="113"/>
        <source>seconds</source>
        <translation>sekunder</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="120"/>
        <source>With this option enabled whatever entry you select from the grub boot menu will be saved as the new default for future boots</source>
        <translation>Når valgmuligheden er aktiveret, så gemmes det du vælger fra grub-opstartsmenuen som den nye standard til fremtidige opstarter</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="123"/>
        <source>Enable saving last boot choice</source>
        <translation>Aktivér husk sidst valgte opstart</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="136"/>
        <source>Background</source>
        <translation>Baggrund</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="154"/>
        <source>Image</source>
        <translation>Billede</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="167"/>
        <location filename="mainwindow.ui" line="269"/>
        <source>Enable theme</source>
        <translation>Aktivér tema</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="247"/>
        <source>Splash</source>
        <translation>Billede</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="282"/>
        <source>Preview</source>
        <translation>Forhåndsvis</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="305"/>
        <source>Messages</source>
        <translation>Meddelelser</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="311"/>
        <source>Very detailed</source>
        <translation>Meget detaljeret</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="318"/>
        <source>Detailed (default setting)</source>
        <translation>Detaljeret (standardindstilling)</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="328"/>
        <source>Limited</source>
        <translation>Begrænset</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="344"/>
        <source>Display log</source>
        <translation>Vis log</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="397"/>
        <source>Display help </source>
        <translation>Vis hjælp</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="400"/>
        <source>Help</source>
        <translation>Hjælp</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="407"/>
        <source>Alt+H</source>
        <translation>Alt+H</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="439"/>
        <source>About this application</source>
        <translation>Om programmet</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="442"/>
        <source>About...</source>
        <translation>Om...</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="449"/>
        <source>Alt+B</source>
        <translation>Alt+B</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="484"/>
        <source>Quit application</source>
        <translation>Afslut programmet</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="487"/>
        <location filename="mainwindow.cpp" line="665"/>
        <source>Close</source>
        <translation>Luk</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="494"/>
        <source>Alt+N</source>
        <translation>Alt+N</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="535"/>
        <source>Apply</source>
        <translation>Anvend</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="66"/>
        <source>Still running</source>
        <translation>Kører stadig</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="66"/>
        <source>Process still running. Are you sure you want to quit?</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="163"/>
        <source>Installing bootsplash, please wait</source>
        <translation>Installer opstartsbillede, vent venligst</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="170"/>
        <source>Updating sources</source>
        <translation>Opdaterer kilder</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="172"/>
        <source>Installing</source>
        <translation>Installerer</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="176"/>
        <location filename="mainwindow.cpp" line="318"/>
        <source>Error</source>
        <translation>Fejl</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="176"/>
        <source>Could not install the bootsplash.</source>
        <translation>Kunne ikke installere opstartsbilledet.</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="274"/>
        <location filename="mainwindow.cpp" line="324"/>
        <source>Cannot continue</source>
        <translation>Kan ikke fortsætte</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="274"/>
        <source>Nothing was selected, cannot change boot options. Exiting...</source>
        <translation>Intet blev valgt, kan ikke ændre opstartsvalgmuligheder. Afslutter...</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="319"/>
        <source>Could not create a temporary folder</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="324"/>
        <source>Cannot create chroot environment, cannot change boot options. Exiting...</source>
        <translation>Kan ikke oprette chroot-miljø, kan ikke ændre opstartsvalgmuligheder. Afslutter...</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="561"/>
        <location filename="mainwindow.cpp" line="857"/>
        <source>Updating configuration, please wait</source>
        <translation>Opdaterer konfiguration, vent venligst</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="608"/>
        <source>Updating initramfs...</source>
        <translation>Opdaterer initramfs...</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="617"/>
        <location filename="mainwindow.cpp" line="869"/>
        <source>Updating grub...</source>
        <translation>Opdaterer grub...</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="621"/>
        <source>Done</source>
        <translation>Færdig</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="621"/>
        <source>Changes have been successfully applied.</source>
        <translation>Ændringerne er blevet anvendt.</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="634"/>
        <source>About</source>
        <translation>Om</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="635"/>
        <source>Version: </source>
        <translation>Version: </translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="636"/>
        <source>Program for selecting common start-up choices</source>
        <translation>Program til at være almindelige opstartsvalg</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="638"/>
        <source>Copyright (c) MX Linux</source>
        <translation>Ophavsret (c) MX Linux</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="639"/>
        <location filename="mainwindow.cpp" line="649"/>
        <source>License</source>
        <translation>Licens</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="640"/>
        <location filename="mainwindow.cpp" line="654"/>
        <source>Changelog</source>
        <translation>Ændringlog</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="641"/>
        <source>Cancel</source>
        <translation>Annuller</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="684"/>
        <source>MX Boot Options</source>
        <translation>MX Opstartsvalgmuligheder</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="695"/>
        <source>Running in a Virtual Machine</source>
        <translation>Kører i en virtuel maskine</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="696"/>
        <source>You current system is running in a Virtual Machine,
Plymouth bootsplash will work in a limited way, you also won&apos;t be able to preview the theme</source>
        <translation>Dit nuværende system kører i en virtuel maskine,
Plymouth-opstartsbillede virker på en begrænset måde og du vil heller ikke være i stand til at forhåndsvise temaet</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="701"/>
        <source>Plymouth packages not installed</source>
        <translation>Plymouth-pakker ikke installeret</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="701"/>
        <source>Plymouth packages are not currently installed.
OK to go ahead and install them?</source>
        <translation>Plymouth-pakker er ikke installeret.
Er det OK at fortsætte og installere dem?</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="721"/>
        <source>Images (*.png *.jpg *.jpeg *.tga)</source>
        <translation>Billeder (*.png *.jpg *.jpeg *.tga)</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="823"/>
        <source>Press any key to close</source>
        <translation>Tryk på en tast for at lukke</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="825"/>
        <source>Log not found</source>
        <translation>Log ikke fundet</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="825"/>
        <source>Could not find log at </source>
        <translation>Kunne ikke finde log i</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="838"/>
        <source>Needs reboot</source>
        <translation>Behøver genstart</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="838"/>
        <source>Plymouth was just installed, you might need to reboot before being able to display previews</source>
        <translation>Plymouth blev lige installeret, det kan være nødvendigt at genstarte inden du kan vise forhåndsvisninger</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="891"/>
        <source>Click to select theme</source>
        <translation>Klik for at vælge tema</translation>
    </message>
</context>
<context>
    <name>QApplication</name>
    <message>
        <location filename="main.cpp" line="42"/>
        <source>Program for selecting common start-up choices</source>
        <translation>Program til at være almindelige opstartsvalg</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="main.cpp" line="61"/>
        <source>Error</source>
        <translation>Fejl</translation>
    </message>
    <message>
        <location filename="main.cpp" line="62"/>
        <source>You seem to be logged in as root, please log out and log in as normal user to use this program.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="720"/>
        <source>Select image to display in bootloader</source>
        <translation>Vælg billede som skal vises i opstartsindlæser</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="901"/>
        <source>Select GRUB theme</source>
        <translation>Vælg GRUB-tema</translation>
    </message>
</context>
</TS>